      PROGRAM CHARGE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     PROGRAM TO CALCULATE CHARGE STATES OF THREE-COMPONENT SYSTEMS
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      CHARACTER*1 CHR
      CHARACTER*30 file,user_name,file_name,pfad
      INTEGER ios

      COMMON /RESULT1/ EIKO_1,EIKO_2,BORN_1,BORN_2,REC_1,REC_2
      COMMON /RESULT2/ D_CAPT,D_IONIS
      COMMON /RESULT3/ FE0,FE1,FE2
      COMMON /RESULT4/ F00,F01,F02
      COMMON /RESULT5/ F10,F11,F12
      COMMON /RESULT6/ F20,F21,F22
      COMMON /RESULT7/ FREEEL_C
      COMMON /RESULT8/ ETHICK_M,ETHICK_A,TAU_M
      COMMON /INITCSD/ FR0,FR1,FR2,R_INIT,D0,D1,D2
      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Constants and units
C     according to 
C     Particle Physics Booklet (Particle Data Group), July 1996
       AU_FC    = 931.494320000000D00    ! atomic mass unit in MeV 
       EM_FC    =   0.510999060000D00    ! electron mass in MeV
       C_FC     =   2.997924580000D+10   ! speed of light in cm/s
       A0_FC    =   0.529177249000D-08   ! Bohr radius in cm
       RY_FC    =  13.605698100000D00    ! Rydberg in eV
       PI_FC    =   3.141592654000D00    ! Pi
       ALPHA_FC =   7.297352521000D-03   ! fine-structure constant
       U_FC     =   1.660540000000D-21   ! atomic mass unit in mg 
       BARN     =   1.000000000000D+24   ! barn in cm2
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      
C     Neue Version (5.12.97):
      CALL GETENV('HOME',user_name)

990   WRITE(*,*) ' Name of output file.................=: out.dat'
      READ (5,'(A20)',ERR=990) file
      IF (file .EQ. ' ') THEN 
          file='out.dat' 
      ENDIF
      OPEN(UNIT=26,FILE=file,status='unknown')
      WRITE(*,*) ' Data will be written to ',file
      WRITE(*,*) ' '

      Z_P     = 79.D0
      Z_T     = 13.D0
      E_KIN   = 1000.D0
      TTHICK_M= 100.D0
      R_INIT  = 0.
      FR0     = 1.
      FR1     = 0.
      FR2     = 0.

1     CONTINUE
      CALL DPROMPT(' Z(proj.)............................=',Z_P)
      CALL DPROMPT(' Z(target)...........................=',Z_T)
      CALL DPROMPT(' E(kin).......................(MeV/u)=',E_KIN)
      CALL DPROMPT(' Target thickness............(mg/cm2)=',TTHICK_M)
2     CALL DPROMPT(' Initial charge state......(0,1,2,-1)=',R_INIT)

      IF(R_INIT.EQ.-1) THEN
        CALL DPROMPT(' Fraction 0  .................:=',FR0)
        CALL DPROMPT(' Fraction 1  .................:=',FR1)
        CALL DPROMPT(' Fraction 2  .................:=',FR2)
      ENDIF

      FRSUM = FR0 + FR1 + FR2
      IF (FRSUM .NE. 1.0) THEN
        WRITE(*,*) 'WRONG INPUT:'
        WRITE(*,*) 'SUM OF Fraction 0 + Fraction 1 + Fraction 2 MUST
     &YIELD UNITY !'     
        GOTO 2
      ENDIF

      CALL CSD(Z_P,Z_T,E_KIN,TTHICK_M,TTHICK_A)

      EIKO_1 = EIKO_1*BARN
      EIKO_2 = EIKO_2*BARN
      BORN_1 = BORN_1*BARN
      BORN_2 = BORN_2*BARN
      REC_1  = REC_1 *BARN
      REC_2  = REC_2 *BARN
      D_CAPT = D_CAPT*BARN
      D_IONIS= D_IONIS*BARN

CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Output on screen and file begins:
      Do 9999 JI=6,26,20
      NOUT = JI
      WRITE(NOUT,50)
      WRITE(NOUT,100) Z_P,Z_T,E_KIN
      WRITE(NOUT,110)
      WRITE(NOUT,50)

      WRITE(NOUT,120)
      WRITE(NOUT,130) EIKO_1,EIKO_2
      WRITE(NOUT,60)
      WRITE(NOUT,160)
      write(NOUT,170) REC_1,REC_2
      WRITE(NOUT,60)
      WRITE(NOUT,140)
      WRITE(NOUT,150) BORN_1,BORN_2
      WRITE(NOUT,60)
      WRITE(NOUT,180)
      WRITE(NOUT,190) D_CAPT,D_IONIS

      WRITE(NOUT,50)
      WRITE(NOUT,05)
      WRITE(NOUT,07)
      WRITE(NOUT,10) FE0,FE1,FE2
      WRITE(NOUT,60)
      WRITE(NOUT,54) ETHICK_M,ETHICK_A
      WRITE(NOUT,56) TAU_M
      WRITE(NOUT,50)

      WRITE(NOUT,08)
      WRITE(NOUT,09)
      WRITE(NOUT,55) TTHICK_M,TTHICK_A
      WRITE(NOUT,10) D0,D1,D2

      WRITE(NOUT,60)
      WRITE(NOUT,15) Z_P,0
      WRITE(NOUT,10) F00,F01,F02
      WRITE(NOUT,60)
      WRITE(NOUT,15) Z_P-1,1
      WRITE(NOUT,10) F10,F11,F12
      WRITE(NOUT,60)
      WRITE(NOUT,15) Z_P-2,2
      WRITE(NOUT,10) F20,F21,F22
      WRITE(NOUT,60)
9999  CONTINUE

05    FORMAT(15X,' >>> EQUILIBRIUM CHARGE-STATE DISTRIBIUTION  <<<')
07    FORMAT(15X,' >>> --------------------------------------  <<<')
08    FORMAT(15X,' >>> CHARGE-STATE DISTRIBIUTION AFTER TARGET <<<')
09    FORMAT(15X,' >>> --------------------------------------- <<<')
10    FORMAT(1X,'0 el.:',1PE10.3,7X,'1 el.:',1PE10.3,7X,'2 el.:',1PE10.3
     &)
15    FORMAT(1X,'>>> Initial charge state Q =',F6.2,2X,'(',I1,' el.)','
     &  <<<')
50    FORMAT(79('-'))
54    FORMAT(' Equilibrium thickness =',1PE10.3,' mg/cm2  =',1PE10.3,' a
     &toms/cm2 ')
55    FORMAT(' Target thickness =',1PE10.3,' mg/cm2  =',1PE10.3,' atoms/
     &cm2 ')
56    FORMAT(' Equilibrium thickness (Thieberger et al.) =',1PE11.4,' mg
     &/cm2 ')
60    FORMAT(1X)
100   FORMAT(3x,' Z(proj.)=',1PE10.4,'  Z(target)=',1PE10.4,'  E(kin) (M
     &eV/u) =',1PE10.4)
110   FORMAT(3x,' >>>>>>>>       All cross sections in barn (1E-24 cm2) 
     &       <<<<<<<<')
120   FORMAT(15X,'  Non-radiative electron capture (NRC)')
130   FORMAT(1X,'EIKO (01) = ',1PE14.4,'  EIKO (12) =',1PE14.4)
140   FORMAT(15X,'  Ionization cross section ')
150   FORMAT(1X,'BORN (10) = ',1PE14.4,'  BORN (21) =',1PE14.4)
160   FORMAT(15X,'  Radiative electron capture (REC)')
170   FORMAT(1X,'REC  (01) = ',1PE14.4,'  REC  (12) =',1PE14.4)
180   FORMAT(15X,'  Double cross sections')
190   FORMAT(1X,'DCAP (02) = ',1PE14.4,'  DION (20) =',1PE14.4,/)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      WRITE(6,*) 'CONTINUE?      (Y/y):'
      READ(*,'(1A)') CHR
      IF (INDEX('Nn',CHR).EQ.0) GOTO 1
      CLOSE(UNIT=6)
      CLOSE(UNIT=26)

      STOP
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE DPROMPT(C_STRING,R_VAL)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     User interface, screen prompt
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT REAL*8 (A-H,O-Z)
      INTEGER ISTMIN,ISTMAX,ISTDOT,ISTEXP
      INTEGER IMINS,IMAXS,IDOTS,IEXPS
      CHARACTER*(*)  C_STRING
      CHARACTER*(80) C_PROMPT
      CHARACTER*(10) C_VAL
      CHARACTER*(80) C_IN
      CHARACTER*(81) C_INP1
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      WRITE(C_VAL,1000) R_VAL
1000  FORMAT(G10.4E2)
      C_PROMPT = C_STRING // ':' // C_VAL

100   WRITE(6,*) C_PROMPT(1:ISTMAX(C_PROMPT)+2)
      READ (5,1002,ERR=100,END=200) C_IN
1002  FORMAT(A80)

      IDOTS   = ISTDOT(C_IN)
      IEXPS   = ISTEXP(C_IN)
      IMAXS   = ISTMAX(C_IN)
      IMINS   = ISTMIN(C_IN)

C     EMPTY STRING ==> END
      IF (IMAXS.EQ.0) GOTO 200

C     TEST OF BLANK
      DO 1, I=IMINS,IMAXS,1
1     IF (C_IN(I:I).EQ.' ') GOTO 100

C     EXPONENT < 100
      I = 2
      IF
     &((C_IN(IEXPS+1:IEXPS+1).EQ.'+').OR.(C_IN(IEXPS+1:IEXPS+1).EQ.'-'))
     & I = 3
      IF ((IEXPS.NE.0).AND.((IMAXS-IEXPS).GT.I)) GOTO 100

C     INSERT DOT IF NEEDED
      IF      ((IDOTS.EQ.0).AND.(IEXPS.EQ.0)) THEN
         C_INP1 = C_IN(1:IMAXS) // '.' // C_IN(IMAXS+1:LEN(C_IN))
      ELSEIF  ((IDOTS.EQ.0).AND.(IEXPS.NE.0)) THEN
         C_INP1 = C_IN(1:IEXPS-1) // '.' // C_IN(IEXPS:LEN(C_IN))
      ELSE
         C_INP1 = C_IN
      ENDIF

C     CONVERSION
      READ (C_INP1,1003,ERR=100) R_IN
1003  FORMAT(F81.20)
      R_VAL = R_IN

200   CONTINUE
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC


      INTEGER FUNCTION ISTMAX(C_STRING)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      CHARACTER C_STRING*(*)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 1, ISTMAX=LEN(C_STRING),1,-1
1     IF (C_STRING(ISTMAX:ISTMAX).NE.' ') GOTO 2
      ISTMAX =0
2     CONTINUE
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC


      INTEGER FUNCTION ISTMIN(C_STRING)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      CHARACTER C_STRING*(*)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 1, ISTMIN=1,LEN(C_STRING),1
1     IF (C_STRING(ISTMIN:ISTMIN).NE.' ') GOTO 2
2     CONTINUE
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC


      INTEGER FUNCTION ISTDOT(C_STRING)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      CHARACTER C_STRING*(*)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 1, ISTDOT=1,LEN(C_STRING),1
1     IF (C_STRING(ISTDOT:ISTDOT).EQ.'.') GOTO 2
      ISTDOT = 0
2     CONTINUE
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC


      INTEGER FUNCTION ISTEXP(C_STRING)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      CHARACTER C_STRING*(*)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      DO 1, ISTEXP=1,LEN(C_STRING),1
1     IF (C_STRING(ISTEXP:ISTEXP).EQ.'E') GOTO 3
      DO 2, ISTEXP=1,LEN(C_STRING),1
2     IF (C_STRING(ISTEXP:ISTEXP).EQ.'e') GOTO 3
      ISTEXP = 0
3     CONTINUE
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
