      SUBROUTINE ION(Z_P,Z_T,E_KIN,SIGION)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Calculates K-shell ionization cross section 
C     according to 
C     R.RICE, G.BASBAS, F.D.MCDANIEL, 
C     ATOMIC DATA AND NUCLEAR DATA TABLES 20, 503-511(1977)
C
C     Z_P   : Nuclear charge of projectile
C     Z_T   : Nuclear charge of target
C     E_KIN : Projectile kinetic energy in MeV/u
C     SIGION: Cross section in cm2 
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      CHARACTER*1 CHR

      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      CALL ETATABLE

      SIGMA0 = 4.D0*PI_FC*A0_FC**2*Z_T**2/Z_P**4
      BETA   = DSQRT(E_KIN**2+2.D0*AU_FC*E_KIN)/(E_KIN+AU_FC)
      GAMMA  = 1.D0/DSQRT(1.D0-BETA**2)
      E_K = (-DSQRT(1.D0-(ALPHA_FC*Z_P)**2)+1.D0)
      V_V0   = BETA/ALPHA_FC
      ETA    =(V_V0/Z_P)**2

      IF (ETA.LE.95.D0) THEN
        CALL INTERPOL(FK,ETA)
      ELSE
        CALL EXTRAPOL(FK,ETA)
      END IF

      REL_FAC = 1.D0
      REL_FAC = 1.D0 +(DLOG(GAMMA**2)-BETA**2)/DLOG(2*BETA**2/E_K)

      SIGION = SIGMA0*FK*REL_FAC

      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE EXTRAPOL(FK,ETA)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Find FK by extrapolation
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      C1      = 0.2834D0
      C2      = 1.6476D0
      C3      = 8.0519D0

      ETA_T   = 95.D0
      FK_95   = 2.666D-2

      G_ETA   = C2/(4.D0*ETA)   + C3/(32.D0*ETA**2)
      G_ETA_T = C2/(4.D0*ETA_T) + C3/(32.D0*ETA_T**2)
      D_ETA_T = ETA_T*FK_95 -C1*DLOG(95.D0) + G_ETA_T

      FK      = C1*DLOG(ETA)+D_ETA_T -G_ETA
      FK      = FK/ETA

      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC




      SUBROUTINE INTERPOL(FK,ETA)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Find FK by interpolation
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      DOUBLE PRECISION ETA_T1(25),ETA_T2(25),ETA_T3(25)
      INTEGER INDEX_TAB(25)

      COMMON /ETA_TABLE/ ETA_T1,ETA_T2,ETA_T3,INDEX_TAB
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IF ((ETA.GT.0.10D0).AND.(ETA.LE.1.0D0)) THEN
        ETA_H = 100.D0*ETA
        I_ETA = IDINT(ETA_H)
        DO 10 I=1,22
          IF((INDEX_TAB(I).LE.I_ETA).AND.(INDEX_TAB(I+1).GE.I_ETA)) THEN
            ST=(ETA_T1(I+1)-ETA_T1(I))*100.D0
     &      /(DBLE(INDEX_TAB(I+1))-DBLE(INDEX_TAB(I)))
            B = -ST*DBLE(INDEX_TAB(I+1))/100.D0 + ETA_T1(I+1)
            FK= ST*ETA +B
            RETURN
          END IF
10      CONTINUE
      ELSE IF ((ETA.GT.1.00D0).AND.(ETA.LE.10.D0)) THEN
        ETA_H = 10.D0*ETA
        I_ETA = IDINT(ETA_H)
        DO 20 I=1,22
          IF((INDEX_TAB(I).LE.I_ETA).AND.(INDEX_TAB(I+1).GE.I_ETA)) THEN
            ST=(ETA_T2(I+1)-ETA_T2(I))*10.D0
     &      /(DBLE(INDEX_TAB(I+1))-DBLE(INDEX_TAB(I)))
            B = -ST*DBLE(INDEX_TAB(I+1))/10.D0 + ETA_T2(I+1)
            FK= ST*ETA +B
            RETURN
          END IF
20      CONTINUE
      ELSE IF ((ETA.GT.10.0D0).AND.(ETA.LE.95.D0)) THEN
        ETA_H = 1.D0*ETA
        I_ETA = IDINT(ETA_H)
        DO 30 I=1,22
          IF((INDEX_TAB(I).LE.I_ETA).AND.(INDEX_TAB(I+1).GE.I_ETA)) THEN
            ST=(ETA_T3(I+1)-ETA_T3(I))
     &      /(DBLE(INDEX_TAB(I+1))-DBLE(INDEX_TAB(I)))
            B = -ST*DBLE(INDEX_TAB(I+1)) + ETA_T3(I+1)
            FK= ST*ETA +B
            RETURN
          END IF
30      CONTINUE
      END IF
      WRITE(*,*) 'FK in subroutine ION out of limits'
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE ETATABLE
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Table with values for ETA
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)      
      DOUBLE PRECISION ETA_T1(25),ETA_T2(25),ETA_T3(25)
      INTEGER INDEX_TAB(25)

      COMMON /ETA_TABLE/ ETA_T1,ETA_T2,ETA_T3,INDEX_TAB
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C       0.1 <= ETA <= 0.95
        ETA_T1(1)  = 4.1180D-2
        ETA_T1(2)  = 6.2920D-2
        ETA_T1(3)  = 8.7600D-2
        ETA_T1(4)  = 1.1420D-1
        ETA_T1(5)  = 1.4200D-1
        ETA_T1(6)  = 1.7030D-1
        ETA_T1(7)  = 2.2620D-1
        ETA_T1(8)  = 2.7940D-1
        ETA_T1(9)  = 3.2820D-1
        ETA_T1(10) = 3.7220D-1
        ETA_T1(11) = 4.1130D-1
        ETA_T1(12) = 4.5350D-1
        ETA_T1(13) = 4.8880D-1
        ETA_T1(14) = 5.1820D-1
        ETA_T1(15) = 5.4220D-1
        ETA_T1(16) = 5.6170D-1
        ETA_T1(17) = 5.7730D-1
        ETA_T1(18) = 5.8950D-1
        ETA_T1(19) = 5.9880D-1
        ETA_T1(20) = 6.0580D-1
        ETA_T1(21) = 6.1070D-1
        ETA_T1(22) = 6.1380D-1
        ETA_T1(23) = 6.1540D-1

C       1. <= ETA <= 9.5
        ETA_T2(1)  = 6.1540D-1
        ETA_T2(2)  = 6.1120D-1
        ETA_T2(3)  = 5.9650D-1
        ETA_T2(4)  = 5.7670D-1
        ETA_T2(5)  = 5.5490D-1
        ETA_T2(6)  = 5.3250D-1
        ETA_T2(7)  = 4.9080D-1
        ETA_T2(8)  = 4.5260D-1
        ETA_T2(9)  = 4.1900D-1
        ETA_T2(10) = 3.8950D-1
        ETA_T2(11) = 3.6380D-1
        ETA_T2(12) = 3.3590D-1
        ETA_T2(13) = 3.1190D-1
        ETA_T2(14) = 2.9120D-1
        ETA_T2(15) = 2.7310D-1
        ETA_T2(16) = 2.5720D-1
        ETA_T2(17) = 2.4310D-1
        ETA_T2(18) = 2.3050D-1
        ETA_T2(19) = 2.1930D-1
        ETA_T2(20) = 2.0910D-1
        ETA_T2(21) = 1.9980D-1
        ETA_T2(22) = 1.9140D-1
        ETA_T2(23) = 1.8370D-1

C       10. <= ETA <= 95.
        ETA_T3(1)  = 1.8370D-1
        ETA_T3(2)  = 1.5850D-1
        ETA_T3(3)  = 1.3960D-1
        ETA_T3(4)  = 1.2490D-1
        ETA_T3(5)  = 1.1320D-1
        ETA_T3(6)  = 1.0350D-1
        ETA_T3(7)  = 8.8690D-2
        ETA_T3(8)  = 7.7700D-2
        ETA_T3(9)  = 6.9230D-2
        ETA_T3(10) = 6.2510D-2
        ETA_T3(11) = 5.7040D-2
        ETA_T3(12) = 5.1470D-2
        ETA_T3(13) = 4.6940D-2
        ETA_T3(14) = 4.3170D-2
        ETA_T3(15) = 4.0000D-2
        ETA_T3(16) = 3.7280D-2
        ETA_T3(17) = 3.4920D-2
        ETA_T3(18) = 3.2860D-2
        ETA_T3(19) = 3.1040D-2
        ETA_T3(20) = 2.9420D-2
        ETA_T3(21) = 2.7970D-2
        ETA_T3(22) = 2.6660D-2

        INDEX_TAB(1)  = 10
        INDEX_TAB(2)  = 12
        INDEX_TAB(3)  = 14
        INDEX_TAB(4)  = 16
        INDEX_TAB(5)  = 18
        INDEX_TAB(6)  = 20
        INDEX_TAB(7)  = 24
        INDEX_TAB(8)  = 28
        INDEX_TAB(9)  = 32
        INDEX_TAB(10) = 36
        INDEX_TAB(11) = 40
        INDEX_TAB(12) = 45
        INDEX_TAB(13) = 50
        INDEX_TAB(14) = 55
        INDEX_TAB(15) = 60
        INDEX_TAB(16) = 65
        INDEX_TAB(17) = 70
        INDEX_TAB(18) = 75
        INDEX_TAB(19) = 80
        INDEX_TAB(20) = 85
        INDEX_TAB(21) = 90
        INDEX_TAB(22) = 95
        INDEX_TAB(23) = 100

        RETURN
        END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

