      SUBROUTINE NRC(Z_P,Z_T,E_KIN,SIGMA01,SIGMA12)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Calculates NRC cross section
C                                                           
C     Z_P      : Nuclear charge of projectile
C     Z_T      : Nuclear charge of target
C     E_KIN    : Projectile kinetic energy in MeV/u
C     SIGMAij  : NRC cross section for state i --> state j
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      CHARACTER*3  C_ZT
      CHARACTER*40 C_FILE
      CHARACTER*80 COMMENT
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      I = IDINT(Z_T)
      WRITE(C_ZT,170) I
170   FORMAT(I3)
      IF (I.GE.100) THEN
        J = 1
      ELSE IF (I.GE.10) THEN
        J = 2
      ELSE
        J = 3
      END IF
      C_FILE = 'x'//C_ZT(J:3)//'.data'
      OPEN(UNIT=27,FILE= C_FILE,STATUS='OLD',ERR=9999)    

      ZP1    = Z_P
      ZT1    = Z_T
      ZTS1   = ZTS
      SIGMA01 = 0.0D0
      SIGMA12 = 0.0D0
      SIGALL = 0.0D0

      DO 200 IEL=0,1
        READ(27,*) NUM
        DO 100 J=1,NUM
          READ(27,'(A80)') COMMENT
          READ(27,*) Z_T
          READ(27,*) ZTS
          READ(27,*) NIMIN
          READ(27,*) NIMAX
          READ(27,*) NFMIN
          READ(27,*) NFMAX

          IF (IEL.EQ.1) THEN
            IF (J.EQ.1)   THEN
              Z_P = ZP1 - 0.3D0
            ELSE
              Z_P = ZP1 - 1.0D0
            END IF
          END IF

          CALL EIKONALS
     &    (Z_T,Z_P,ZTS,NIMIN,NIMAX,NFMIN,NFMAX,E_KIN,IEL,SIGSUM)
          SIGALL = SIGALL + SIGSUM

100     CONTINUE
      IF (IEL.EQ.0) SIGMA01 = SIGALL
      IF (IEL.EQ.1) SIGMA12 = SIGALL
      SIGALL = 0.0D0
      REWIND  27
200   CONTINUE
      CLOSE(27)
      Z_P = ZP1
      Z_T = ZT1

      RETURN
9999  WRITE(6,*) 'ALLOCATION ERROR FILE: ',C_FILE
      WRITE(6,*) '*      CREATE NEW FILE !         *'

      Z_P = ZP1
      Z_T = ZT1
      ZTS= ZTS1
      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE EIKONALS
     &(Z_T,Z_P,ZTS,NIMIN,NIMAX,NFMIN,NFMAX,E_KIN,IEL,SIGSUM)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      INTEGER I,F,I_TEST
      INTEGER NIMIN,NIMAX,NFMIN,NFMAX,IEL
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      SIGSUM = 0.0D0
      DO 20 I=NIMIN,NIMAX
        NI=I
        DO 10 F=NFMIN,NFMAX
          NF=F
          ZPX  = Z_P
          ZTX  = Z_T
          ZTSX = ZTS
          CALL EIKONAL(Z_T,Z_P,ZTS,NI,NF,E_KIN,SIGMAX)
          Z_P   = ZPX
          Z_T   = ZTX
          ZTS   = ZTSX

          SIGMA = SIGMAX*2.D0*NI**2*NF**2
C                                          ASSUME FULL INITIAL S SHELL
          IF ((F.EQ.1).AND.(IEL.EQ.1)) THEN
             SIGMA = SIGMAX*NI**2*NF**2
          END IF
C                                       FINAL S SHELL HAS ONE ELECTRON
          SIGSUM = SIGSUM + SIGMA
10      CONTINUE
20    CONTINUE


      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE EIKONAL(Z_T,Z_P,ZTS,NI,NF,E_KIN,SIGMA)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Relativistic Eikonal Approximation 
C     according to
C     W.E.Meyerhof and R.Anholt, Phys. Rev. A32, 3291 (1985).
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC  
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      AU       = AU_FC
      A0       = A0_FC
      ALPHA    = ALPHA_FC
      PI       = PI_FC
      RY       = RY_FC
      ALPHA    = 1.D0/137.036D0

C______ _______RELATIVISTISCHE ATOMARE ENERGIEN ________________________
        IF (NI.EQ.1) THEN
         E_INITAL = 1.D0/ALPHA**2*DSQRT(1.D0-ALPHA**2*Z_T**2)
        ELSE
         E_INITAL = 1.D0/ALPHA**2*DSQRT(1.D0-ALPHA**2*Z_T**2/NI**2)
        END IF
        IF (NF.EQ.1) THEN
         E_FINAL = 1.D0/ALPHA**2*DSQRT(1.D0-ALPHA**2*Z_P**2)
        ELSE
         E_FINAL = 1.D0/ALPHA**2*DSQRT(1.D0-ALPHA**2*Z_P**2/NF**2)
        END IF

        Z_P = Z_P/NF
        Z_T = Z_T/NI
        ZTS=ZTS/NI
C_______________________________________________________________________
        BETA   = DSQRT(E_KIN**2+2.D0*AU*E_KIN)/(E_KIN+AU)
        V      = BETA/ALPHA
        ETA    = 1.D0/V
        GAMMA  = 1.D0/DSQRT(1.D0-BETA**2)
        DELTA  = DSQRT( (-1.D0+GAMMA)/(1.D0+GAMMA) )
        P_     = ETA*(E_FINAL/GAMMA-E_INITAL)
        ALPHA  = 1.D0/137.D0
C_______________S_ORB___________________________________________________
      S_ORB  =5.D0*PI*DELTA*ALPHA*(1.D0/18.D0*(Z_P+Z_T)-
     &        1.D0/36.D0*DELTA**2*(Z_P+Z_T)-
     &        1.D0/8.D0/PI*Z_T*ETA*ZTS*(1.D0-0.5D0*DELTA**2)-
     &        1.D0/18.D0* GAMMA/(GAMMA+1.D0)*Z_P*ZTS/Z_T+
     &        1.D0/28.D0*(GAMMA/(GAMMA+1.D0))**2*Z_P*(ZTS/Z_T)**2-
     &        1.D0/28.D0* GAMMA/(GAMMA+1.D0)*(Z_P+Z_T-DELTA**2*Z_P)*
     &        ZTS/Z_T)
C_______________S_MAGN__________________________________________________
      S_MAGN = -DELTA**2+5.D0/16.D0*DELTA**4+5.D0/8.D0*DELTA**2*
     &          GAMMA/(GAMMA+1.D0)*ZTS/Z_T+0.25D0*DELTA**2*ETA**2*ZTS**2
     &         +5.D0/48.D0*DELTA**4*ETA**2*ZTS**2
C_______________S_EIK___________________________________________________
      S_EIK  = 1.D0+5.D0/4.D0*ETA*ZTS/Z_T*P_+5.D0/12.D0*ETA**2*(ZTS
     &          /Z_T*P_)**2+1.D0/6.D0*(ETA*ZTS)**2
C_______________SIGMA___________________________________________________
      SIGMA1  = 2.D0**8*(Z_P*Z_T)**5/(5.D0*V**2*(Z_T**2+P_**2)**5)
     &          *(1.D0+GAMMA)/(2.D0*GAMMA**2)
     &          *PI*ETA*ZTS
     &          /DSINH(PI*ETA*ZTS)
     &          *DEXP(-2.D0*ETA*ZTS*DATAN(-P_/Z_T) )
     &          *(S_EIK+S_ORB+S_MAGN)
 
      SIGMA   = SIGMA1*PI*A0**2
C_______________________________________________________________________

        RETURN
        END

