      SUBROUTINE REC(Z_P,Z_T,E_KIN,SIGREC)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Calculates REC cross section
C     
C     Z_P   : Nuclear charge of projectile 
C     Z_T   : Nuclear charge of target
C     E_KIN : Projectile kinetic energy in MeV/u
C     SIGREC: cross section in cm2
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON/RESULT7/FREEEL_C
      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Number of quasi-free target electrons 
      CALL FELEC(Z_T,E_KIN,FREEEL)
C     K-REC cross section per electron
      CALL KREC(Z_P,E_KIN,SIGKREC)

      SIGREC = 1.2002D0*FREEEL*SIGKREC
      FREEEL_C = FREEEL

      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE KREC(Z_P,E_KIN,SIGKREC)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Calculates K-REC cross section per electron     
C 
C     Z_T   : Nuclear charge of target
C     E_KIN : Projectile kinetic energy in MeV/u
C     SIGREC: cross section in cm2
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)

      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      E_K = (-DSQRT(1.0D0-(Z_P*ALPHA_FC)**2)+1.0D0)*510.9D0
      EK_REC = E_K+E_KIN*1000.D0/1823.0D0
      ETAK   = DSQRT(E_K/(EK_REC-E_K))
      EK     = ETAK**2/(1+ETAK**2)
      BK     = DEXP(-4*ETAK*ATAN(1./ETAK))/(1-DEXP(-2*PI_FC*ETAK))

      SIGKREC= 9.165*1.D-21*ETAK**2*EK**2*BK

      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC



      SUBROUTINE FELEC(Z_T,E_KIN,FREEEL)
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C     Calculates number of quasi-free target electrons
C
C     Z_T   : Nuclear charge of target
C     E_KIN : Projectile kinetic energy in MeV/u
C     FREEEL: Number of quasi-free target electrons
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      IMPLICIT DOUBLE PRECISION(A-H,O-Z)
      DOUBLE PRECISION Z_AB(4)

      COMMON /CONSTAN/ AU_FC,EM_FC,C_FC,ALPHA_FC,A0_FC,RY_FC,PI_FC,U_FC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
      Z_AB(1) = 0.3D0
      Z_AB(2) = 4.15D0
      Z_AB(3) = 11.25D0
      Z_AB(4) = 27.85D0

      FREEEL = Z_T
      DO 100 N=1,4
        E_BIN  = (-DSQRT(1.0D0-((Z_T-Z_AB(N))*ALPHA_FC/N)**2)+1.0D0)*
     &           EM_FC*1.0D3
        BETA_P = DSQRT(E_KIN**2+2.D0*AU_FC*E_KIN)/(E_KIN+AU_FC)
        BETA_E = DSQRT(E_BIN**2+2.D0*EM_FC*1.0D3*E_BIN)/
     &           (E_BIN+EM_FC*1.0D3)
        VER    = BETA_E/BETA_P
        IF (VER.LE.0.2D0) GOTO 200
        FREEEL = FREEEL - 2*N**2
        IF (FREEEL.LE.0.0D0) GOTO 150
100   CONTINUE
      GOTO 200
150   FREEEL = 0.0D0
200   CONTINUE

      RETURN
      END
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC






